@@ -55,13 +55,14 @@ $voti = file("$percorso_cartella_voti/voti$num_giornata_2_cifre.txt");
 $num_voti = count($voti);
 for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
 $dati_voto = explode($separatore_campi_file_voti, $voti[$num1]);
-$num_calciatore = $dati_voto[($num_colonna_numcalciatore_file_voti-1)];
+$num_calciatore = $dati_voto[($num_colonna_numcalciatore_file_voti - 1)];
 $num_calciatore = togli_acapo($num_calciatore);
-$voto_tot[$num_calciatore] = $dati_voto[($num_colonna_vototot_file_voti-1)];
-$voto_tot[$num_calciatore] = togli_acapo($voto_tot[$num_calciatore]);
-$voto_tot[$num_calciatore] = str_replace(",",".",$voto_tot[$num_calciatore]);
+$voto_calciatore = $dati_voto[($num_colonna_vototot_file_voti - 1)];
+$voto_calciatore = togli_acapo($voto_calciatore);
+$voto_calciatore = str_replace(",",".",$voto_calciatore);
+$voto_tot[$num_calciatore] = $voto_calciatore + 0.0;
 $voto_giornale[$num_calciatore] = $dati_voto[($num_colonna_votogiornale_file_voti-1)];
-$voto_giornale[$num_calciatore] = togli_acapo($voto_giornale[$num_calciatore]);
+$voto_giornale[$num_calciatore] = togli_acapo($voto_giornale[$num_calciatore]) + 0.0;
 } # fine for $num1
 
 
@@ -112,6 +113,7 @@ $sostituisci_D = 0;
 $sostituisci_C = 0;
 $sostituisci_F = 0;
 $sostituisci_A = 0;
+settype($voti_tot[$giocatore],"double");
 $voti_tot[$giocatore] = 0;
 $schema_attuale = "00000";
 $num_sostituisci = 0;
