@@ -161,8 +161,8 @@ $squadra1 = $giocatore_numero[$partita[0]];
 $squadra2 = $giocatore_numero[$partita[1]];
 $scontri_diretti .= $squadra1."##@@&&".$squadra2."
 ";
-
 } # fine if ($campionato_in_corso == "SI")
+
 if ($inizio_giornata == "SI") {
 $inizio_giornata = "";
 if ($linea_file_scontri > $ultima_giornata) $ultima_giornata = $linea_file_scontri;
@@ -183,16 +183,17 @@ if ($giornata_in_corso == "SI" or !$ultima_giornata or $ultima_giornata == 0) $f
 else {
 $verifica_num = ereg_replace("[0-9]","",$ultima_giornata);
 if ($verifica_num != "") $finito_scontri = "SI";
-else $num_giornata_campionato = $num_giornata_campionato - (floor($num_giornata_campionato/$ultima_giornata)*$ultima_giornata);
+else $num_giornata_campionato = $num_giornata_campionato - $ultima_giornata;
 } # fine else if ($giornata_in_corso == "SI" or ...)
 $conta_cicli_while++;
-if ($conta_cicli_while >= 50) $finito_scontri = "SI";
+if ($conta_cicli_while >= 500) $finito_scontri = "SI";
 } # fine while ($finito_scontri != "SI")
 } # fine if ($attiva_scontri_diretti == "SI")
 
 
 $filegiornata = fopen("$percorso_cartella_dati/$giornata","w+");
-fwrite($filegiornata,"#@& formazioni #@&
+fwrite($filegiornata,"#@& data #@&".date("d/m/Y H:i")."
+#@& formazioni #@&
 $formazioni#@& fine formazioni #@&
 ");
 if ($attiva_scontri_diretti == "SI") {
