@@ -89,7 +89,7 @@ $frase .= "L'offerta non  abbastanza alta per comprare il calciatore.<br>";
 else {
 if ($prima_offerta == "SI" and ($costo_mostra + $min_rilancio_dopo_offerta_iniziale - 1) >= $valore_offerta) {
 $inserire = "NO";
-$frase .= "L'offerta non  abbastanza alta per comprare il calciatore (in quanto seconnda offerta si devono offrire almeno ".($costo_mostra + $min_rilancio_dopo_offerta_iniziale)." fanta-euro).<br>";
+$frase .= "L'offerta non  abbastanza alta per comprare il calciatore (in quanto seconda offerta si devono offrire almeno ".($costo_mostra + $min_rilancio_dopo_offerta_iniziale)." fanta-euro).<br>";
 } # fine if ($prima_offerta == "SI" and ($costo_mostra + $min_rilancio_dopo_offerta_iniziale - 1) >= $valore_offerta)
 } # fine else if ($costo >= $valore_offerta)
 } # fine if ($num_calciatore == $numero)
@@ -176,6 +176,28 @@ flock($file_mercato,2);
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 
 if ($posizione == $num1) {
+
+$prima_offerta_assoluta = "SI";
+if (@is_file("$percorso_cartella_voti/calciatori_iniziali.txt")) {
+$prima_offerta_assoluta = "NO";
+$calciatori_iniziali = file("$percorso_cartella_voti/calciatori_iniziali.txt");
+$num_calciatori_iniziali = count($calciatori_iniziali);
+$nuovi_calciatori_iniziali = "";
+for ($num2 = 0 ; $num2 < $num_calciatori_iniziali ; $num2++) {
+$dati_calciatore_ini = explode($separatore_campi_file_calciatori, $calciatori_iniziali[$num2]);
+$numero_ini = togli_acapo($dati_calciatore_ini[($num_colonna_numcalciatore_file_calciatori-1)]);
+if ($numero_ini == $num_calciatore) $prima_offerta_assoluta = "SI";
+else $nuovi_calciatori_iniziali .= $calciatori_iniziali[$num2];
+} # fine for $num2
+if ($prima_offerta_assoluta == "SI") {
+$filecalciniziali = fopen("$percorso_cartella_voti/calciatori_iniziali.txt","w+");
+flock($filecalciniziali,2);
+fwrite($filecalciniziali,$nuovi_calciatori_iniziali);
+flock($filecalciniziali,3);
+fclose($filecalciniziali);
+} # fine if ($prima_offerta_assoluta == "SI")
+} # fine if (@is_file("$percorso_cartella_voti/calciatori_iniziali.txt"))
+
 $anno_attuale = date("Y");
 $mese_attuale = date("m");
 $giorno_attuale = date("d");
@@ -184,7 +206,7 @@ $minuto_attuale = date("i");
 $scadenza = date("YmdHi",mktime($ora_attuale+$aspetta_ore,$minuto_attuale+$aspetta_minuti,0,$mese_attuale,$giorno_attuale+$aspetta_giorni,$anno_attuale));
 $linea = "$num_calciatore,$nome,$ruolo,$valore_offerta,$nome_utente,$scadenza";
 
-if ($nuova_offerta == "SI" and $min_rilancio_dopo_offerta_iniziale != 1) $linea .= ",###PRIMA_OFFERTA###";
+if ($nuova_offerta == "SI" and $min_rilancio_dopo_offerta_iniziale != 1 and $prima_offerta_assoluta == "SI") $linea .= ",###PRIMA_OFFERTA###";
 
 if ($vecchio_proprietario) {
 $linea .= ",$vecchio_proprietario,$vecchio_costo";
