@@ -131,6 +131,8 @@ echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcol
 $tab_comprati = "";
 $soldi_spesi = 0;
 $num_calciatori_posseduti = 0;
+unset($sec_restanti_vett);
+unset($riga_tab_mercato);
 $adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
 for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
 $vecchio_proprietario = "";
@@ -156,10 +158,8 @@ $minuto_off = substr($tempo_off,10,2);
 $sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti < 0) {
 $tempo_restante = "COMPRATO";
-if ($nome_utente == $proprietario) 
-$offri = "<a href=\"vendi.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">vendi</a>";
-else
-$offri = "<font size=-2><a href=\"scambia.php?num_calciatore=$numero&altro_utente=$proprietario&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">scambia</a></font>";
+if ($nome_utente == $proprietario) $offri = "<a href=\"vendi.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">vendi</a>";
+else $offri = "<font size=-2><a href=\"scambia.php?num_calciatore=$numero&altro_utente=$proprietario&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">scambia</a></font>";
 $tab_comprati .= "<tr><td>$numero</td>
 <td>$nome</td>
 <td>$ruolo</td>
@@ -191,8 +191,9 @@ if ($vecchio_proprietario) { $proprietario_mostra = "$proprietario <font size=-2
 else { $proprietario_mostra = $proprietario; }
 if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
 else { $costo_mostra = $costo; }
-if ($prima_offerta == "SI" and $min_rilancio_dopo_offerta_iniziale != 1) $proprietario_mostra .= "<font size=-2> (1)</font>";
-echo "<tr><td>$numero</td>
+if ($prima_offerta == "SI" and $min_rilancio_dopo_offerta_iniziale != 1) $proprietario_mostra .= "<font size=-2>&nbsp;(1)</font>";
+$sec_restanti_vett[$numero] = $sec_restanti;
+$riga_tab_mercato[$numero] = "<tr><td>$numero</td>
 <td>$nome</td>
 <td>$ruolo</td>
 <td>$costo_mostra</td>
@@ -203,8 +204,15 @@ echo "<tr><td>$numero</td>
 } # fine if (count($dati_calciatore) >= 6)
 
 } # fine for $num1
+
+if (@is_array($sec_restanti_vett)) {
+asort ($sec_restanti_vett);
+reset ($sec_restanti_vett);
+while (list($key, $val) = each($sec_restanti_vett)) echo $riga_tab_mercato[$key];
+} # fine if (@is_array($sec_restanti_vett))
 echo "$tab_comprati</table>";
 
+
 $num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
 $surplus = @file("$percorso_cartella_dati/squadra_$nome_utente");
 $surplus = $surplus[0];
