@@ -20,7 +20,7 @@
 ##################################################################################
 
 
-include("controlla_pass.php");
+include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
 
@@ -63,8 +63,7 @@ $calciatori_richiesti = explode(";", $calciatori_richiesti);
 $num_calciatori_richiesti = count($calciatori_richiesti);
 $soldi_richiesti = $dati_scambio[6];
 $tempo_off = $dati_scambio[7];
-$tempo_off = ereg_replace("
-","",$tempo_off);
+$tempo_off = togli_acapo($tempo_off);
 $anno_off = substr($tempo_off,0,4);
 $mese_off = substr($tempo_off,4,2);
 $giorno_off = substr($tempo_off,6,2);
