@@ -94,7 +94,7 @@ else {
 
 
 if (!$sicuro) {
-echo "<form method=\"post\" action=\"$SCRIPT_NAME\">
+echo "<form method=\"post\" action=\"./scambio_accetta.php\">
 Sei sicuro di voler accettare lo scambio proposto da <b>$utente_offerente</b>?&nbsp;
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
@@ -336,4 +336,4 @@ echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
 } # fine if ($pass_errata != "SI")
 
 include("$percorso_cartella_dati/foot.php");
-?>
\ No newline at end of file
+?>
